Application Programming Interface
=================================

Types
-----
.. automodule:: plum._type
    :members:

Signatures
----------
.. automodule:: plum._signature
    :members:

Methods
-------
.. automodule:: plum._method
    :members:

Functions
---------
.. automodule:: plum._function
    :members:

Dispatchers
-----------
.. automodule:: plum._dispatcher
    :members:
.. automodule:: plum._resolver
    :members:

Parametric Classes
------------------
.. automodule:: plum._parametric
    :members:

Promotion and Conversion
------------------------
.. automodule:: plum._promotion
    :members:

Union Aliases
-------------
.. automodule:: plum._alias
    :members:

iPython AutoReload
------------------
.. automodule:: plum._autoreload
    :members:

Other Utilities
---------------
.. automodule:: plum.repr
    :members:
.. automodule:: plum._util
    :members:
